@@ -1,7 +1,7 @@
 """
 Type annotations for backup-gateway service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/literals/)
 
 Usage::
 
@@ -156,6 +156,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
