@@ -1,7 +1,7 @@
 """
 Type annotations for backup-gateway service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/type_defs/)
 
 Usage::
 
@@ -44,12 +44,15 @@ __all__ = (
     "HypervisorTypeDef",
     "ImportHypervisorConfigurationInputRequestTypeDef",
     "ImportHypervisorConfigurationOutputTypeDef",
+    "ListGatewaysInputListGatewaysPaginateTypeDef",
     "ListGatewaysInputRequestTypeDef",
     "ListGatewaysOutputTypeDef",
+    "ListHypervisorsInputListHypervisorsPaginateTypeDef",
     "ListHypervisorsInputRequestTypeDef",
     "ListHypervisorsOutputTypeDef",
     "ListTagsForResourceInputRequestTypeDef",
     "ListTagsForResourceOutputTypeDef",
+    "ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef",
     "ListVirtualMachinesInputRequestTypeDef",
     "ListVirtualMachinesOutputTypeDef",
     "PaginatorConfigTypeDef",
@@ -190,6 +193,13 @@ ImportHypervisorConfigurationOutputTypeDef = TypedDict(
     },
 )
 
+ListGatewaysInputListGatewaysPaginateTypeDef = TypedDict(
+    "ListGatewaysInputListGatewaysPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListGatewaysInputRequestTypeDef = TypedDict(
     "ListGatewaysInputRequestTypeDef",
     {
@@ -207,6 +217,13 @@ ListGatewaysOutputTypeDef = TypedDict(
     },
 )
 
+ListHypervisorsInputListHypervisorsPaginateTypeDef = TypedDict(
+    "ListHypervisorsInputListHypervisorsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListHypervisorsInputRequestTypeDef = TypedDict(
     "ListHypervisorsInputRequestTypeDef",
     {
@@ -240,6 +257,13 @@ ListTagsForResourceOutputTypeDef = TypedDict(
     },
 )
 
+ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef = TypedDict(
+    "ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListVirtualMachinesInputRequestTypeDef = TypedDict(
     "ListVirtualMachinesInputRequestTypeDef",
     {
